@@ -11,32 +11,27 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""
-To run this template just do:
-python generative_adversarial_net.py
+"""To run this template just do: python generative_adversarial_net.py.
 
 After a few epochs, launch TensorBoard to see the images being generated at every batch:
 
 tensorboard --logdir default
 """
-import os
 from argparse import ArgumentParser, Namespace
 
 import numpy as np
 import torch
 import torch.nn as nn
-import torch.nn.functional as F  # noqa
-from torch.utils.data import DataLoader
+import torch.nn.functional as F
 
 from pl_examples import cli_lightning_logo
-from pl_examples.basic_examples.mnist_datamodule import MNIST
-from pytorch_lightning.core import LightningDataModule, LightningModule
+from pl_examples.basic_examples.mnist_datamodule import MNISTDataModule
+from pytorch_lightning.core import LightningModule
 from pytorch_lightning.trainer import Trainer
 from pytorch_lightning.utilities.imports import _TORCHVISION_AVAILABLE
 
 if _TORCHVISION_AVAILABLE:
     import torchvision
-    from torchvision import transforms
 
 
 class Generator(nn.Module):
@@ -214,35 +209,6 @@ class GAN(LightningModule):
         self.logger.experiment.add_image("generated_images", grid, self.current_epoch)
 
 
-class MNISTDataModule(LightningDataModule):
-    """
-    >>> MNISTDataModule()  # doctest: +ELLIPSIS
-    <...generative_adversarial_net.MNISTDataModule object at ...>
-    """
-
-    def __init__(self, batch_size: int = 64, data_path: str = os.getcwd(), num_workers: int = 4):
-        super().__init__()
-        self.batch_size = batch_size
-        self.data_path = data_path
-        self.num_workers = num_workers
-
-        self.transform = transforms.Compose([transforms.ToTensor(), transforms.Normalize([0.5], [0.5])])
-        self.dims = (1, 28, 28)
-
-    def prepare_data(self, stage=None):
-        # Use this method to do things that might write to disk or that need to be done only from a single GPU
-        # in distributed settings. Like downloading the dataset for the first time.
-        MNIST(self.data_path, train=True, download=True, transform=transforms.ToTensor())
-
-    def setup(self, stage=None):
-        # There are also data operations you might want to perform on every GPU, such as applying transforms
-        # defined explicitly in your datamodule or assigned in init.
-        self.mnist_train = MNIST(self.data_path, train=True, transform=self.transform)
-
-    def train_dataloader(self):
-        return DataLoader(self.mnist_train, batch_size=self.batch_size, num_workers=self.num_workers)
-
-
 def main(args: Namespace) -> None:
     # ------------------------
     # 1 INIT LIGHTNING MODEL
@@ -252,7 +218,7 @@ def main(args: Namespace) -> None:
     # ------------------------
     # 2 INIT TRAINER
     # ------------------------
-    # If use distubuted training  PyTorch recommends to use DistributedDataParallel.
+    # If use distributed training  PyTorch recommends to use DistributedDataParallel.
     # See: https://pytorch.org/docs/stable/nn.html#torch.nn.DataParallel
     dm = MNISTDataModule.from_argparse_args(args)
     trainer = Trainer.from_argparse_args(args)
