@@ -21,6 +21,7 @@ import os
 from argparse import Namespace
 from typing import Any, Dict, Optional, Union
 
+import numpy as np
 import torch
 from torch.utils.tensorboard import SummaryWriter
 from torch.utils.tensorboard.summary import hparams
@@ -63,17 +64,19 @@ class TensorBoardLogger(LightningLoggerBase):
             directory for existing versions, then automatically assigns the next available version.
             If it is a string then it is used as the run-specific subdirectory name,
             otherwise ``'version_${version}'`` is used.
-        sub_dir: Sub-directory to group TensorBoard logs. If a sub_dir argument is passed
-            then logs are saved in ``/save_dir/version/sub_dir/``. Defaults to ``None`` in which
-            logs are saved in ``/save_dir/version/``.
         log_graph: Adds the computational graph to tensorboard. This requires that
             the user has defined the `self.example_input_array` attribute in their
             model.
         default_hp_metric: Enables a placeholder metric with key `hp_metric` when `log_hyperparams` is
             called without a metric (otherwise calls to log_hyperparams without a metric are ignored).
         prefix: A string to put at the beginning of metric keys.
-        \**kwargs: Additional arguments like `comment`, `filename_suffix`, etc. used by
-            :class:`SummaryWriter` can be passed as keyword arguments in this logger.
+        sub_dir: Sub-directory to group TensorBoard logs. If a sub_dir argument is passed
+            then logs are saved in ``/save_dir/version/sub_dir/``. Defaults to ``None`` in which
+            logs are saved in ``/save_dir/version/``.
+        \**kwargs: Additional arguments used by :class:`SummaryWriter` can be passed as keyword
+            arguments in this logger. To automatically flush to disk, `max_queue` sets the size
+            of the queue for pending logs before flushing. `flush_secs` determines how many seconds
+            elapses before flushing.
 
     """
     NAME_HPARAMS_FILE = "hparams.yaml"
@@ -106,10 +109,10 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @property
     def root_dir(self) -> str:
-        """
-        Parent directory for all tensorboard checkpoint subdirectories.
-        If the experiment name parameter is ``None`` or the empty string, no experiment subdirectory is used
-        and the checkpoint will be saved in "save_dir/version_dir"
+        """Parent directory for all tensorboard checkpoint subdirectories.
+
+        If the experiment name parameter is ``None`` or the empty string, no experiment subdirectory is used and the
+        checkpoint will be saved in "save_dir/version_dir"
         """
         if self.name is None or len(self.name) == 0:
             return self.save_dir
@@ -117,10 +120,10 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @property
     def log_dir(self) -> str:
-        """
-        The directory for this run's tensorboard checkpoint. By default, it is named
-        ``'version_${self.version}'`` but it can be overridden by passing a string value
-        for the constructor's version parameter instead of ``None`` or an int.
+        """The directory for this run's tensorboard checkpoint.
+
+        By default, it is named ``'version_${self.version}'`` but it can be overridden by passing a string value for the
+        constructor's version parameter instead of ``None`` or an int.
         """
         # create a pseudo standard path ala test-tube
         version = self.version if isinstance(self.version, str) else f"version_{self.version}"
@@ -133,10 +136,20 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @property
     def save_dir(self) -> Optional[str]:
+        """Gets the save directory where the TensorBoard experiments are saved.
+
+        Returns:
+            The local path to the save directory where the TensorBoard experiments are saved.
+        """
         return self._save_dir
 
     @property
     def sub_dir(self) -> Optional[str]:
+        """Gets the sub directory where the TensorBoard experiments are saved.
+
+        Returns:
+            The local path to the sub directory where the TensorBoard experiments are saved.
+        """
         return self._sub_dir
 
     @property
@@ -164,10 +177,9 @@ class TensorBoardLogger(LightningLoggerBase):
     def log_hyperparams(
         self, params: Union[Dict[str, Any], Namespace], metrics: Optional[Dict[str, Any]] = None
     ) -> None:
-        """
-        Record hyperparameters. TensorBoard logs with and without saved hyperparameters
-        are incompatible, the hyperparameters are then not displayed in the TensorBoard.
-        Please delete or move the previously saved logs to display the new ones with hyperparameters.
+        """Record hyperparameters. TensorBoard logs with and without saved hyperparameters are incompatible, the
+        hyperparameters are then not displayed in the TensorBoard. Please delete or move the previously saved logs
+        to display the new ones with hyperparameters.
 
         Args:
             params: a dictionary-like container with the hyperparameters
@@ -228,7 +240,9 @@ class TensorBoardLogger(LightningLoggerBase):
 
             if input_array is not None:
                 input_array = model._apply_batch_transfer_handler(input_array)
+                model._running_torchscript = True
                 self.experiment.add_graph(model, input_array)
+                model._running_torchscript = False
             else:
                 rank_zero_warn(
                     "Could not log computational graph since the"
@@ -257,10 +271,20 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @property
     def name(self) -> str:
+        """Get the name of the experiment.
+
+        Returns:
+            The name of the experiment.
+        """
         return self._name
 
     @property
     def version(self) -> int:
+        """Get the experiment version.
+
+        Returns:
+            The experiment version if specified else the next version.
+        """
         if self._version is None:
             self._version = self._get_next_version()
         return self._version
@@ -286,6 +310,12 @@ class TensorBoardLogger(LightningLoggerBase):
 
         return max(existing_versions) + 1
 
+    @staticmethod
+    def _sanitize_params(params: Dict[str, Any]) -> Dict[str, Any]:
+        params = LightningLoggerBase._sanitize_params(params)
+        # logging of arrays with dimension > 1 is not supported, sanitize as string
+        return {k: str(v) if isinstance(v, (torch.Tensor, np.ndarray)) and v.ndim > 1 else v for k, v in params.items()}
+
     def __getstate__(self):
         state = self.__dict__.copy()
         state["_experiment"] = None
