@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, Sequence, Union
+from typing import Any, List, Optional, Sequence
 
 from deprecate.utils import void
 from torch.utils.data import DataLoader
@@ -11,7 +11,7 @@ from pytorch_lightning.utilities.types import _PREDICT_OUTPUT
 
 
 class PredictionLoop(DataLoaderLoop):
-    """Loop to run over dataloaders for prediction"""
+    """Loop to run over dataloaders for prediction."""
 
     def __init__(self):
         super().__init__()
@@ -24,7 +24,7 @@ class PredictionLoop(DataLoaderLoop):
 
     @property
     def return_predictions(self) -> bool:
-        """Whether to return the predictions or not"""
+        """Whether to return the predictions or not."""
         return self._return_predictions
 
     @return_predictions.setter
@@ -41,7 +41,7 @@ class PredictionLoop(DataLoaderLoop):
 
     @property
     def num_dataloaders(self) -> int:
-        """Returns the number of prediction dataloaders"""
+        """Returns the number of prediction dataloaders."""
         # case where user does:
         # return dl1, dl2
         dataloaders = self.dataloaders
@@ -60,7 +60,7 @@ class PredictionLoop(DataLoaderLoop):
 
     @property
     def dataloaders(self) -> Sequence[DataLoader]:
-        """Returns all prediction dataloaders"""
+        """Returns all prediction dataloaders."""
         return self.trainer.predict_dataloaders
 
     @property
@@ -72,19 +72,19 @@ class PredictionLoop(DataLoaderLoop):
         self.epoch_loop = epoch_loop
 
     def reset(self) -> None:
-        """Resets the internal state of the loop for a new run"""
+        """Resets the internal state of the loop for a new run."""
         super().reset()
         self.predictions = []
         self.epoch_batch_indices = []
 
     def on_run_start(self) -> None:
-        """Calls ``on_predict_start`` hook"""
-        self.on_predict_start()
+        """Calls ``_on_predict_start`` hook."""
+        self._on_predict_start()
 
     def advance(self, *args: Any, **kwargs: Any) -> None:
-        """Predicts one entire dataloader"""
+        """Predicts one entire dataloader."""
         void(*args, **kwargs)
-        dataloader = self.trainer.accelerator.process_dataloader(self.current_dataloader)
+        dataloader = self.trainer.training_type_plugin.process_dataloader(self.current_dataloader)
         dataloader_iter = enumerate(dataloader)
         dl_max_batches = self.max_batches[self.current_dataloader_idx]
 
@@ -94,33 +94,31 @@ class PredictionLoop(DataLoaderLoop):
         self.predictions.append(dl_predictions)
         self.epoch_batch_indices.append(dl_batch_indices)
 
-    def on_run_end(self) -> Union[List[Any], List[List[Any]]]:
-        """Calls ``on_predict_epoch_end`` and ``on_predict_end`` hooks and returns results from all dataloaders"""
-        results = self.on_predict_epoch_end()
-        self.on_predict_end()
+    def on_run_end(self) -> _PREDICT_OUTPUT:
+        """Calls ``on_predict_epoch_end`` and ``on_predict_end`` hooks and returns results from all dataloaders."""
+        results = self._on_predict_epoch_end()
+        self._on_predict_end()
         return results
 
-    def on_predict_start(self) -> None:
-        """
-        Sets model to eval mode and disables gradients. Also calls ``on_predict_start`` and
-        ``on_predict_epoch_start`` hooks.
+    def _on_predict_start(self) -> None:
+        """Sets model to eval mode and disables gradients.
+
+        Also calls ``on_predict_start`` and ``on_predict_epoch_start`` hooks.
         """
         # enable eval mode + no grads
-        self.on_predict_model_eval()
+        self._on_predict_model_eval()
         self.trainer.lightning_module.zero_grad()
 
         # hook
         self.trainer.call_hook("on_predict_start")
         self.trainer.call_hook("on_predict_epoch_start")
 
-    def on_predict_epoch_end(self) -> Optional[_PREDICT_OUTPUT]:
+    def _on_predict_epoch_end(self) -> Optional[_PREDICT_OUTPUT]:
         """Calls ``on_predict_epoch_end`` hook.
 
         Returns:
             the results for all dataloaders
         """
-        self.trainer.profiler.describe()
-
         results = self.predictions
 
         self.trainer.call_hook("on_predict_epoch_end", results)
@@ -128,8 +126,8 @@ class PredictionLoop(DataLoaderLoop):
         if self.return_predictions:
             return results[0] if self.num_dataloaders == 1 else results
 
-    def on_predict_end(self) -> None:
-        """Resets previous gradient status and calls ``on_predict_end`` hook"""
+    def _on_predict_end(self) -> None:
+        """Resets previous gradient status and calls ``on_predict_end`` hook."""
         # clear memory. the predictions are extracted in `on_predict_epoch_end`.
         self.predictions = []
         self.epoch_batch_indices = []
@@ -137,7 +135,7 @@ class PredictionLoop(DataLoaderLoop):
         # hook
         self.trainer.call_hook("on_predict_end")
 
-    def on_predict_model_eval(self):
-        """Calls ``on_predict_model_eval`` hook"""
+    def _on_predict_model_eval(self):
+        """Calls ``on_predict_model_eval`` hook."""
         model_ref = self.trainer.lightning_module
         model_ref.on_predict_model_eval()
