@@ -20,8 +20,7 @@ from pytorch_lightning.plugins.environments import ClusterEnvironment
 
 
 class LSFEnvironment(ClusterEnvironment):
-    """
-    An environment for running on clusters managed by the LSF resource manager.
+    """An environment for running on clusters managed by the LSF resource manager.
 
     It is expected that any execution using this ClusterEnvironment was executed
     using the Job Step Manager i.e. ``jsrun``.
@@ -53,7 +52,8 @@ class LSFEnvironment(ClusterEnvironment):
         required_env_vars = ("LSB_JOBID", "LSB_HOSTS", "JSM_NAMESPACE_LOCAL_RANK", "JSM_NAMESPACE_SIZE")
         return all(v in os.environ for v in required_env_vars)
 
-    def creates_children(self) -> bool:
+    @property
+    def creates_processes_externally(self) -> bool:
         return True
 
     def master_address(self):
@@ -104,10 +104,8 @@ class LSFEnvironment(ClusterEnvironment):
         return int(local_rank)
 
     def node_rank(self):
-        """
-        The node rank is determined by the position of the current hostname in the list of hosts stored in
-        the environment variable `LSB_HOSTS`.
-        """
+        """The node rank is determined by the position of the current hostname in the list of hosts stored in the
+        environment variable `LSB_HOSTS`."""
         hosts = self._read_hosts()
         count = {}
         for host in hosts:
@@ -125,7 +123,7 @@ class LSFEnvironment(ClusterEnvironment):
         hosts = hosts.split()
         if len(hosts) < 2:
             raise ValueError(
-                "Cannot parse hosts from LSB_HOSTS environment variable." ' Expected format: "batch <rank_0_host> ..."'
+                'Cannot parse hosts from LSB_HOSTS environment variable. Expected format: "batch <rank_0_host> ..."'
             )
         return hosts
 
@@ -135,8 +133,8 @@ class LSFEnvironment(ClusterEnvironment):
 
     @staticmethod
     def _get_master_port():
-        """
-        A helper function for accessing the master port.
+        """A helper function for accessing the master port.
+
         Uses the LSF job ID so all ranks can compute the master port.
         """
         # check for user-specified master port
