@@ -12,32 +12,36 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from pprint import pprint
-from typing import Any, Dict, Iterable, Mapping, Optional, Union
+from typing import Any, Dict, Iterable, List, Optional, Union
 
 import torch
 
 import pytorch_lightning as pl
-from pytorch_lightning.core import memory
 from pytorch_lightning.loggers import LightningLoggerBase, LoggerCollection, TensorBoardLogger
-from pytorch_lightning.trainer.connectors.logger_connector.result import _METRIC, MetricSource
+from pytorch_lightning.trainer.connectors.logger_connector.result import _METRICS, _OUT_DICT, _PBAR_DICT
 from pytorch_lightning.trainer.states import RunningStage, TrainerFn
-from pytorch_lightning.utilities import DeviceType
+from pytorch_lightning.utilities import DeviceType, memory
 from pytorch_lightning.utilities.apply_func import apply_to_collection, move_data_to_device
 from pytorch_lightning.utilities.metrics import metrics_to_scalars
-from pytorch_lightning.utilities.types import _EVALUATE_OUTPUT
+from pytorch_lightning.utilities.warnings import rank_zero_deprecation
 
 
 class LoggerConnector:
     def __init__(self, trainer: "pl.Trainer", log_gpu_memory: Optional[str] = None) -> None:
         self.trainer = trainer
+        if log_gpu_memory is not None:
+            rank_zero_deprecation(
+                "Setting `log_gpu_memory` with the trainer flag is deprecated in v1.5 and will be removed in v1.7. "
+                "Please monitor GPU stats with the `DeviceStatsMonitor` callback directly instead."
+            )
         self.log_gpu_memory = log_gpu_memory
-        self.eval_loop_results = []
+        self.eval_loop_results: List[_OUT_DICT] = []
         self._val_log_step: int = 0
         self._test_log_step: int = 0
-        self._progress_bar_metrics: Dict[str, float] = {}
-        self._logged_metrics: Dict[str, _METRIC] = {}
-        self._callback_metrics: Dict[str, _METRIC] = {}
-        self._gpus_metrics: Dict[str, str] = {}
+        self._progress_bar_metrics: _PBAR_DICT = {}
+        self._logged_metrics: _OUT_DICT = {}
+        self._callback_metrics: _OUT_DICT = {}
+        self._gpus_metrics: Dict[str, float] = {}
         self._epoch_end_reached = False
         self._current_fx: Optional[str] = None
         self._batch_idx: Optional[int] = None
@@ -46,11 +50,18 @@ class LoggerConnector:
     def on_trainer_init(
         self,
         logger: Union[bool, LightningLoggerBase, Iterable[LightningLoggerBase]],
-        flush_logs_every_n_steps: int,
+        flush_logs_every_n_steps: Optional[int],
         log_every_n_steps: int,
         move_metrics_to_cpu: bool,
     ) -> None:
         self.configure_logger(logger)
+        if flush_logs_every_n_steps is not None:
+            rank_zero_deprecation(
+                f"Setting `Trainer(flush_logs_every_n_steps={flush_logs_every_n_steps})` is deprecated in v1.5 "
+                "and will be removed in v1.7. Please configure flushing in the logger instead."
+            )
+        else:
+            flush_logs_every_n_steps = 100  # original default parameter
         self.trainer.flush_logs_every_n_steps = flush_logs_every_n_steps
         self.trainer.log_every_n_steps = log_every_n_steps
         self.trainer.move_metrics_to_cpu = move_metrics_to_cpu
@@ -66,23 +77,23 @@ class LoggerConnector:
         return should_log_every_n_steps or self.trainer.should_stop
 
     def configure_logger(self, logger: Union[bool, LightningLoggerBase, Iterable[LightningLoggerBase]]) -> None:
-        if logger is True:
+        if isinstance(logger, bool):
             # default logger
-            self.trainer.logger = TensorBoardLogger(
-                save_dir=self.trainer.default_root_dir, version=self.trainer.slurm_job_id, name="lightning_logs"
+            self.trainer.logger = (
+                TensorBoardLogger(
+                    save_dir=self.trainer.default_root_dir, version=self.trainer.slurm_job_id, name="lightning_logs"
+                )
+                if logger
+                else None
             )
-        elif logger is False:
-            self.trainer.logger = None
+        elif isinstance(logger, Iterable):
+            self.trainer.logger = LoggerCollection(logger)
         else:
-            if isinstance(logger, Iterable):
-                self.trainer.logger = LoggerCollection(logger)
-            else:
-                self.trainer.logger = logger
+            self.trainer.logger = logger
 
-    def log_metrics(self, metrics: Dict[str, _METRIC], step: Optional[int] = None) -> None:
-        """Logs the metric dict passed in.
-        If `step` parameter is None and `step` key is presented is metrics,
-        uses metrics["step"] as a step
+    def log_metrics(self, metrics: _OUT_DICT, step: Optional[int] = None) -> None:
+        """Logs the metric dict passed in. If `step` parameter is None and `step` key is presented is metrics, uses
+        metrics["step"] as a step.
 
         Args:
             metrics: Metric values
@@ -97,17 +108,17 @@ class LoggerConnector:
 
         if step is None:
             step = scalar_metrics.pop("step", None)
+
+        self._logged_metrics.update(scalar_metrics)
+
         if step is None:
             # added metrics for convenience
             scalar_metrics.setdefault("epoch", self.trainer.current_epoch)
             step = self.trainer.global_step
 
         # log actual metrics
-        if self.trainer.is_global_zero:
-            self.trainer.logger.agg_and_log_metrics(scalar_metrics, step=step)
-            self.trainer.logger.save()
-
-        self._logged_metrics.update(scalar_metrics)
+        self.trainer.logger.agg_and_log_metrics(scalar_metrics, step=step)
+        self.trainer.logger.save()
 
     """
     Evaluation metric updates
@@ -127,27 +138,23 @@ class LoggerConnector:
         elif self.trainer.state.stage is RunningStage.TESTING:
             self._test_log_step += 1
 
-    def on_evaluation_batch_start(self, batch: Any, batch_idx: int, dataloader_idx: int, num_dataloaders: int) -> None:
+    def on_evaluation_batch_start(self, dataloader_idx: int, num_dataloaders: int) -> None:
         model = self.trainer.lightning_module
         # set dataloader_idx only if multiple ones
         model._current_dataloader_idx = dataloader_idx if num_dataloaders > 1 else None
 
-        # track batch_size
-        self.trainer._results.extract_batch_size(batch)
-        self._batch_idx = batch_idx
-
     def update_eval_step_metrics(self) -> None:
         if self.trainer.sanity_checking:
             return
 
         # logs user requested information to logger
         assert not self._epoch_end_reached
-        self.log_metrics(self.metrics[MetricSource.LOG], step=self._eval_log_step)
+        self.log_metrics(self.metrics["log"], step=self._eval_log_step)
 
         # increment the step even if nothing was logged
         self._increment_eval_log_step()
 
-    def _prepare_eval_loop_results(self, metrics: Mapping[str, _METRIC]) -> None:
+    def _prepare_eval_loop_results(self, metrics: _OUT_DICT) -> None:
         if self.trainer.sanity_checking:
             return
 
@@ -163,30 +170,31 @@ class LoggerConnector:
             else:
                 self.eval_loop_results.append(callback_metrics)
 
-    def update_eval_epoch_metrics(self) -> _EVALUATE_OUTPUT:
+    def update_eval_epoch_metrics(self) -> List[_OUT_DICT]:
         assert self._epoch_end_reached
         metrics = self.metrics
 
         if not self.trainer.sanity_checking:
             # log all the metrics as a single dict
-            self.log_metrics(metrics[MetricSource.LOG])
+            self.log_metrics(metrics["log"])
 
-        self._prepare_eval_loop_results(metrics[MetricSource.CALLBACK])
+        self._prepare_eval_loop_results(metrics["callback"])
 
         # log results of evaluation
         if (
-            self.trainer.state.fn != TrainerFn.FITTING
+            self.trainer.state.fn not in (TrainerFn.FITTING, TrainerFn.TUNING)
             and self.trainer.evaluating
             and self.trainer.is_global_zero
             and self.trainer.verbose_evaluate
         ):
             print("-" * 80)
-            for result_idx, results in enumerate(self.eval_loop_results):
-                print(f"DATALOADER:{result_idx} {self.trainer.state.stage.upper()} RESULTS")
+            assert self.trainer.state.stage is not None
+            for i, metrics_dict in enumerate(self.eval_loop_results):
+                print(f"DATALOADER:{i} {self.trainer.state.stage.upper()} RESULTS")
                 pprint(
                     {
                         k: (v.item() if v.numel() == 1 else v.tolist()) if isinstance(v, torch.Tensor) else v
-                        for k, v in results.items()
+                        for k, v in metrics_dict.items()
                     }
                 )
                 print("-" * 80)
@@ -200,41 +208,43 @@ class LoggerConnector:
     Train metric updates
     """
 
-    def on_train_split_start(self, batch_idx: int, split_idx: int, split_batch: Any) -> None:
-        assert self.trainer._results is not None
-        self.trainer._results.extract_batch_size(split_batch)
-        self._batch_idx = batch_idx
+    def on_train_split_start(self, split_idx: int, split_batch: Any) -> None:
         self._split_idx = split_idx
-
-        # clear reference to this step's training loss so that it can be garbage collected before the next training step
-        self.trainer._results.minimize = None
+        self.on_new_batch(split_batch)
 
     def update_train_step_metrics(self) -> None:
-        if self.trainer.fit_loop.should_accumulate() and self.trainer.lightning_module.automatic_optimization:
+        if self.trainer.fit_loop._should_accumulate() and self.trainer.lightning_module.automatic_optimization:
             return
 
+        # TODO: remove this call in v1.7
         self._log_gpus_metrics()
 
         # when metrics should be logged
         assert not self._epoch_end_reached
         if self.should_update_logs or self.trainer.fast_dev_run:
-            self.log_metrics(self.metrics[MetricSource.LOG])
+            self.log_metrics(self.metrics["log"])
 
     def update_train_epoch_metrics(self) -> None:
         # add the metrics to the loggers
         assert self._epoch_end_reached
-        self.log_metrics(self.metrics[MetricSource.LOG])
+        self.log_metrics(self.metrics["log"])
 
         # reset result collection for next epoch
+        assert self.trainer._results is not None
         self.trainer._results.reset(metrics=True)
 
-    def _log_gpus_metrics(self):
+    def _log_gpus_metrics(self) -> None:
+        """
+        .. deprecated:: v1.5
+            This function was deprecated in v1.5 in favor of
+            `pytorch_lightning.accelerators.gpu._get_nvidia_gpu_stats` and will be removed in v1.7.
+        """
         for key, mem in self.gpus_metrics.items():
             if self.log_gpu_memory == "min_max":
                 self.trainer.lightning_module.log(key, mem, prog_bar=False, logger=True)
             else:
                 gpu_id = int(key.split("/")[0].split(":")[1])
-                if gpu_id in self.trainer.accelerator_connector.parallel_device_ids:
+                if gpu_id in self.trainer._accelerator_connector.parallel_device_ids:
                     self.trainer.lightning_module.log(
                         key, mem, prog_bar=False, logger=True, on_step=True, on_epoch=False
                     )
@@ -243,38 +253,50 @@ class LoggerConnector:
     Utilities and properties
     """
 
+    def on_new_batch(self, batch: Any) -> int:
+        # when the user requests `dataloader_iter`, we can't track the batch_size
+        # and this is left to user responsibility.
+        if not isinstance(batch, pl.utilities.fetching.StepFuncDataLoaderIter):
+            assert self.trainer._results is not None
+            return self.trainer._results.extract_batch_size(batch)
+        return 1
+
     def on_epoch_start(self) -> None:
         self._epoch_end_reached = False
 
-    def on_batch_start(self) -> None:
+    def on_batch_start(self, batch_idx: int, batch: Any) -> int:
+        self._batch_idx = batch_idx
         self._epoch_end_reached = False
+        return self.on_new_batch(batch)
 
-    def epoch_end_reached(self):
+    def epoch_end_reached(self) -> None:
         self._epoch_end_reached = True
         self._batch_idx = None
         self._split_idx = None
+        assert self.trainer._results is not None
+        self.trainer._results.batch_size = 1
 
     def on_epoch_end(self) -> None:
         assert self._epoch_end_reached
         metrics = self.metrics
-        self._progress_bar_metrics.update(metrics[MetricSource.PBAR])
-        self._callback_metrics.update(metrics[MetricSource.CALLBACK])
-        self._logged_metrics.update(metrics[MetricSource.LOG])
+        self._progress_bar_metrics.update(metrics["pbar"])
+        self._callback_metrics.update(metrics["callback"])
+        self._logged_metrics.update(metrics["log"])
         self._current_fx = None
 
     def on_batch_end(self) -> None:
         assert not self._epoch_end_reached
         metrics = self.metrics
-        self._progress_bar_metrics.update(metrics[MetricSource.PBAR])
-        self._callback_metrics.update(metrics[MetricSource.CALLBACK])
-        self._logged_metrics.update(metrics[MetricSource.LOG])
+        self._progress_bar_metrics.update(metrics["pbar"])
+        self._callback_metrics.update(metrics["callback"])
+        self._logged_metrics.update(metrics["log"])
 
     def should_reset_tensors(self, fx: str) -> bool:
         is_different_fx = self._current_fx != fx
         if self._split_idx is None:
             is_first_batch = self._batch_idx in (None, 0)
         else:
-            is_first_batch = self._batch_idx + self._split_idx == 0
+            is_first_batch = bool(self._batch_idx) + self._split_idx == 0
         return is_different_fx and is_first_batch
 
     def reset_metrics(self) -> None:
@@ -291,40 +313,45 @@ class LoggerConnector:
         self._current_fx = None
 
     @property
-    def metrics(self) -> Dict[MetricSource, Dict[str, _METRIC]]:
+    def metrics(self) -> _METRICS:
         """This function returns either batch or epoch metrics depending on ``_epoch_end_reached``."""
         on_step = not self._epoch_end_reached
+        assert self.trainer._results is not None
         return self.trainer._results.metrics(on_step)
 
     @property
-    def gpus_metrics(self) -> Dict[str, str]:
+    def gpus_metrics(self) -> Dict[str, float]:
+        """
+        .. deprecated:: v1.5
+            Will be removed in v1.7.
+        """
         if self.trainer._device_type == DeviceType.GPU and self.log_gpu_memory:
             mem_map = memory.get_memory_profile(self.log_gpu_memory)
             self._gpus_metrics.update(mem_map)
         return self._gpus_metrics
 
     @property
-    def callback_metrics(self) -> Dict[str, _METRIC]:
+    def callback_metrics(self) -> _OUT_DICT:
         if self.trainer._results:
-            metrics = self.metrics[MetricSource.CALLBACK]
+            metrics = self.metrics["callback"]
             self._callback_metrics.update(metrics)
         return self._callback_metrics
 
     @property
-    def logged_metrics(self) -> Dict[str, _METRIC]:
+    def logged_metrics(self) -> _OUT_DICT:
         if self.trainer._results:
-            metrics = self.metrics[MetricSource.LOG]
+            metrics = self.metrics["log"]
             self._logged_metrics.update(metrics)
         return self._logged_metrics
 
     @property
-    def progress_bar_metrics(self) -> Dict[str, float]:
+    def progress_bar_metrics(self) -> _PBAR_DICT:
         if self.trainer._results:
-            metrics = self.metrics[MetricSource.PBAR]
+            metrics = self.metrics["pbar"]
             self._progress_bar_metrics.update(metrics)
         return self._progress_bar_metrics
 
-    def teardown(self):
+    def teardown(self) -> None:
         args = (torch.Tensor, move_data_to_device, "cpu")
         self._logged_metrics = apply_to_collection(self._logged_metrics, *args)
         self._progress_bar_metrics = apply_to_collection(self._progress_bar_metrics, *args)
