@@ -14,17 +14,18 @@
 import importlib
 import logging
 import os
+import uuid
 from functools import wraps
-from typing import Callable, Optional, Sequence
+from typing import Optional, Sequence
 
 import numpy as np
 import torch
-from torch.optim import Optimizer
 from torch.optim.lr_scheduler import _LRScheduler
 
 import pytorch_lightning as pl
 from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.loggers.base import DummyLogger
+from pytorch_lightning.trainer.optimizers import _get_default_scheduler_config
 from pytorch_lightning.utilities import rank_zero_warn
 from pytorch_lightning.utilities.cloud_io import get_filesystem
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
@@ -97,27 +98,15 @@ class _LRFinder:
         self.results = {}
         self._total_batch_idx = 0  # for debug purpose
 
-    def _exchange_scheduler(self, configure_optimizers: Callable):
-        """Decorate configure_optimizers methods such that it returns the users
-        originally specified optimizer together with a new scheduler that
-        that takes care of the learning rate search.
-        """
+    def _exchange_scheduler(self, trainer: "pl.Trainer"):
+        """Decorate `trainer.init_optimizers` method such that it returns the users originally specified optimizer
+        together with a new scheduler that that takes care of the learning rate search."""
+        init_optimizers = trainer.init_optimizers
 
-        @wraps(configure_optimizers)
-        def func():
-            # Decide the structure of the output from configure_optimizers
-            # Same logic as method `init_optimizers` in trainer/optimizers.py
-            optim_conf = configure_optimizers()
-            if isinstance(optim_conf, Optimizer):
-                optimizers = [optim_conf]
-            elif isinstance(optim_conf, (list, tuple)) and len(optim_conf) == 2 and isinstance(optim_conf[0], list):
-                optimizers, _ = optim_conf
-            elif isinstance(optim_conf, dict):
-                optimizers = [optim_conf["optimizer"]]
-            elif isinstance(optim_conf, (list, tuple)) and isinstance(optim_conf[0], dict):
-                optimizers = [opt_dict["optimizer"] for opt_dict in optim_conf]
-            elif isinstance(optim_conf, (list, tuple)):
-                optimizers = [optim_conf]
+        @wraps(init_optimizers)
+        def func(model):
+            # Decide the structure of the output from init_optimizers
+            optimizers, _, _ = init_optimizers(model)
 
             if len(optimizers) != 1:
                 raise MisconfigurationException(
@@ -134,8 +123,10 @@ class _LRFinder:
 
             args = (optimizer, self.lr_max, self.num_training)
             scheduler = _LinearLR(*args) if self.mode == "linear" else _ExponentialLR(*args)
+            sched_config = _get_default_scheduler_config()
+            sched_config.update({"scheduler": scheduler, "interval": "step"})
 
-            return [optimizer], [{"scheduler": scheduler, "interval": "step"}]
+            return [optimizer], [sched_config], []
 
         return func
 
@@ -171,14 +162,13 @@ class _LRFinder:
         return fig
 
     def suggestion(self, skip_begin: int = 10, skip_end: int = 1):
-        """This will propose a suggestion for choice of initial learning rate
-        as the point with the steepest negative gradient.
+        """This will propose a suggestion for choice of initial learning rate as the point with the steepest
+        negative gradient.
 
         Returns:
             lr: suggested initial learning rate to use
             skip_begin: how many samples to skip in the beginning. Prevent too naive estimates
             skip_end: how many samples to skip in the end. Prevent too optimistic estimates
-
         """
         try:
             loss = np.array(self.results["loss"][skip_begin:-skip_end])
@@ -211,7 +201,7 @@ def lr_find(
     if update_attr:
         lr_attr_name = _determine_lr_attr_name(trainer, model)
 
-    save_path = os.path.join(trainer.default_root_dir, "lr_find_temp_model.ckpt")
+    save_path = os.path.join(trainer.default_root_dir, f"lr_find_temp_model_{uuid.uuid4()}.ckpt")
 
     __lr_finder_dump_params(trainer, model)
 
@@ -225,7 +215,7 @@ def lr_find(
     trainer.callbacks = [_LRCallback(num_training, early_stop_threshold, progress_bar_refresh_rate=1)]
 
     # No logging
-    trainer.logger = DummyLogger()
+    trainer.logger = DummyLogger() if trainer.logger is not None else None
 
     # Max step set to number of iterations
     trainer.fit_loop.max_steps = num_training
@@ -242,7 +232,7 @@ def lr_find(
     trainer.save_checkpoint(str(save_path))
 
     # Configure optimizer and scheduler
-    model.configure_optimizers = lr_finder._exchange_scheduler(model.configure_optimizers)
+    trainer.init_optimizers = lr_finder._exchange_scheduler(trainer)
 
     # Fit, lr & loss logged in callback
     trainer.tuner._run(model)
@@ -288,7 +278,7 @@ def __lr_finder_dump_params(trainer, model):
         "max_steps": trainer.max_steps,
         "checkpoint_callback": trainer.checkpoint_callback,
         "current_epoch": trainer.current_epoch,
-        "configure_optimizers": model.configure_optimizers,
+        "init_optimizers": trainer.init_optimizers,
     }
 
 
@@ -299,14 +289,13 @@ def __lr_finder_restore_params(trainer, model):
     trainer.fit_loop.global_step = trainer.__dumped_params["global_step"]
     trainer.fit_loop.max_steps = trainer.__dumped_params["max_steps"]
     trainer.fit_loop.current_epoch = trainer.__dumped_params["current_epoch"]
-    model.configure_optimizers = trainer.__dumped_params["configure_optimizers"]
+    trainer.init_optimizers = trainer.__dumped_params["init_optimizers"]
     del trainer.__dumped_params
 
 
 class _LRCallback(Callback):
-    """Special callback used by the learning rate finder. This callbacks log
-    the learning rate before each batch and log the corresponding loss after
-    each batch.
+    """Special callback used by the learning rate finder. This callbacks log the learning rate before each batch
+    and log the corresponding loss after each batch.
 
     Args:
         num_training: number of iterations done by the learning rate finder
@@ -318,7 +307,6 @@ class _LRCallback(Callback):
         beta: smoothing value, the loss being logged is a running average of
             loss values logged until now. ``beta`` controls the forget rate i.e.
             if ``beta=0`` all past information is ignored.
-
     """
 
     def __init__(
@@ -339,7 +327,7 @@ class _LRCallback(Callback):
         self.progress_bar = None
 
     def on_batch_start(self, trainer, pl_module):
-        """Called before each training batch, logs the lr that will be used"""
+        """Called before each training batch, logs the lr that will be used."""
         if (trainer.fit_loop.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
             return
 
@@ -348,8 +336,8 @@ class _LRCallback(Callback):
 
         self.lrs.append(trainer.lr_schedulers[0]["scheduler"].lr[0])
 
-    def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
-        """Called when the training batch ends, logs the calculated loss"""
+    def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx):
+        """Called when the training batch ends, logs the calculated loss."""
         if (trainer.fit_loop.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
             return
 
@@ -378,8 +366,7 @@ class _LRCallback(Callback):
 
 
 class _LinearLR(_LRScheduler):
-    """
-    Linearly increases the learning rate between two boundaries over a number of iterations.
+    """Linearly increases the learning rate between two boundaries over a number of iterations.
 
     Args:
 
@@ -417,8 +404,7 @@ class _LinearLR(_LRScheduler):
 
 
 class _ExponentialLR(_LRScheduler):
-    """Exponentially increases the learning rate between two boundaries
-    over a number of iterations.
+    """Exponentially increases the learning rate between two boundaries over a number of iterations.
 
     Arguments:
 
